F2PY - Fortran to Python Interface Generator
Author: Pearu Peterson
Keywords: fortran,python,interface,f2py,f2py2e,wrapper,fpig

## F2PY old news.

February 23, 2002
  Fixed a bug of incorrect shapes of multi-dimensional arrays when returning from Fortran routine (thanks to Eric for pointing this out). `F2PY_REPORT_ATEXIT` is disabled by default under Win32.
February 14, 2002
  Introduced `callprotoargument` statement so that proper prototypes can be specified (this fixes SEGFAULTs when wrapping C functions with `f2py`, see NEWS.txt for more details). Updated for the latest `numpy_distutils`. Fixed few bugs.
February 3, 2002
  Introduced `intent(overwrite),intent(out=name)` attributes, `callstatement C-expr;` statement, and reviewed reference counting in callback mechanism. Fixed bugs.
January 18, 2002
  Introduced extra keyword argument `copy_#varname#=1` for `intent(copy)` variables, `-DF2PY_REPORT_ATEXIT` for reporting `f2py` performance, `has_column_major_storage` member function for generated modules, and dmalloc support.
January 16, 2002
  BREAKING NEWS! Solved long lasted dilemma of wrapping multi-dimensional arrays where different storage orders in C and Fortran come into account. From now on this difference is dealt automatically by the f2py generated module and in a very efficient way. For example, the corresponding element A(i,j) of a Fortran array can be accessed in Python as A[i,j].
January 13, 2002
  Fifth Public Release is coming soon..., a snapshot is available for download, now with updates.
December 17, 2001
  Fourth Public Release: Win32 support.
  Making `f2py2e` a module. Currently it has only one member function `run_main(comline_list)`.
  Removed command line arguments `-fix,-f90,-f77` and introduced many new ones. See NEWS.txt.
  `intent(..)` statement with empty name list defines default `intent(..)` attribute for all routine arguments.
  Refinements in Win32 support. Eric Jones has provided a f2py HOWTO for Windows users. See win32_notes.txt.
  Major rewrote of the code generator to achieve a higher quality of generated C/API modules (-Wall messages are considerably reduced, especially for callback functions).
  Many bugs were fixed.
December 12, 2001
  Win32 support (thanks to Eric Jones and Tiffany Kamm). Minor cleanups and fixes.
December 4, 2001
  Third Public Release: `f2py` supports `distutils`. It can be installed with one and it generates `setup_modulename.py` to be used for building Python extension modules.
  Introduced `threadsafe`, `fortranname`, and `intent(c)` statements.
August 13, 2001
  Changed the name FPIG to F2PY for avoiding confusion with project names.
  Updated `f2py` for use with Numeric version 20.x.
January 12, 2001
  Example usages of `PyFortranObject`. Fixed bugs. Updated the Python 9 Conference paper (F2PY paper).
December 9, 2000
  Implemented support for `PARAMETER` statement.
November 6, 2000
  Submitted a paper for 9th Python Conference (accepted). It is available in html, PDF, and Gzipped PS formats.
September 17, 2000
  Support for F90/95 module data and routines. COMMON block wrapping is rewritten. New signature file syntax: `pythonmodule`. Signature files generated with f2py-2.264 or earlier, are incompatible (need replacement `module` with `pythonmodule`).
September 12, 2000
  The second public release of `f2py` is out. See Release notes.
September 11, 2000
  Now `f2py` supports wrapping Fortran 90/95 module routines (support for F90/95 module data coming soon)
June 12, 2000
  Now `f2py` has a mailing list f2py-users open for discussion.